C_OK = 1
C_NG = 0

C_CUI = "cui"
C_GUI = "gui"

C_ON = 1
C_OFF = 0

